<?php

namespace Drupal\tr_rulez\Plugin\RulesAction;

/**
 * Provides the 'Clear flood event' action.
 *
 * Makes the flood control mechanism forget an event for the current visitor.
 *
 * @RulesAction(
 *   id = "rules_flood_clear_event",
 *   label = @Translation("Clear flood event"),
 *   category = @Translation("System"),
 *   context_definitions = {
 *     "name" = @ContextDefinition("string",
 *       label = @Translation("Event name"),
 *       description = @Translation("The unique name of the flood event.")
 *     ),
 *     "identifier" = @ContextDefinition("string",
 *       label = @Translation("Identifier"),
 *       description = @Translation("Unique identifier of the current user. Defaults to the current user's IP address."),
 *       default_value = NULL,
 *       required = FALSE
 *     ),
 *   }
 * )
 */
class FloodClearEvent extends RulesFloodActionBase {

  /**
   * Makes the flood control mechanism forget an event for the current visitor.
   *
   * @param string $name
   *   The name of a flood event.
   * @param string $identifier
   *   (optional) Unique identifier of the current user. Defaults to the current
   *   user's IP address.
   */
  protected function doExecute($name, $identifier = NULL) {
    $this->flood->clear($name, $identifier);
    $this->logger->notice('Cleared flood event %name with identifier=%identifier', [
      '%name' => $name,
      '%identifier' => $identifier,
    ]);
  }

}
