<?php

namespace Drupal\tr_rulez\Plugin\RulesAction;

/**
 * Registers an event for the current visitor to the flood control mechanism.
 *
 * @RulesAction(
 *   id = "rules_flood_register_event",
 *   label = @Translation("Register flood event"),
 *   category = @Translation("System"),
 *   context_definitions = {
 *     "name" = @ContextDefinition("string",
 *       label = @Translation("Event name"),
 *       description = @Translation("The unique name of the flood event.")
 *     ),
 *     "window" = @ContextDefinition("integer",
 *       label = @Translation("Window"),
 *       description = @Translation("Number of seconds in the time window for this event."),
 *       default_value = 3600,
 *       required = FALSE
 *     ),
 *     "identifier" = @ContextDefinition("string",
 *       label = @Translation("Identifier"),
 *       description = @Translation("Unique identifier of the current user. Defaults to their IP address."),
 *       default_value = NULL,
 *       required = FALSE
 *     ),
 *   }
 * )
 */
class FloodRegisterEvent extends RulesFloodActionBase {

  /**
   * Registers an event for the current visitor to the flood control mechanism.
   *
   * @param string $name
   *   The name of a flood event.
   * @param int $window
   *   (optional) Number of seconds in the time window for this event (default
   *   is 3600 seconds, or 1 hour).
   * @param string $identifier
   *   (optional) Unique identifier of the current user. Defaults to the current
   *   user's IP address.
   */
  protected function doExecute($name, int $window = 3600, $identifier = NULL) {
    $this->flood->register($name, $window, $identifier);
    $this->logger->notice('Registered flood event %name with window=%window and identifier=%identifier', [
      '%name' => $name,
      '%window' => $window,
      '%identifier' => $identifier,
    ]);
  }

}
